@@ -131,6 +131,9 @@ bool wxStfApp::OnCmdLineParsed(wxCmdLineParser& parser)
 
 bool wxStfApp::OnInit(void)
 {
+#ifndef _STFDEBUG
+    wxLogLevel(wxLOG_FatalError);
+#endif
     if (!wxApp::OnInit()) {
         std::cerr << "Could not start application" << std::endl;
         return false;
