@@ -694,10 +694,10 @@ void wxStfGraph::DoPlot( wxDC* pDC, const Vector_double& trace, int start, int e
 
     switch (pt) {
      case active:
-         yFormatFunc = std::bind1st( std::mem_fun(&wxStfGraph::yFormatD), this);
+         yFormatFunc = std::bind( std::mem_fn(&wxStfGraph::yFormatD), this, std::placeholders::_1);
          break;
      case reference:
-         yFormatFunc = std::bind1st( std::mem_fun(&wxStfGraph::yFormatD2), this);
+         yFormatFunc = std::bind( std::mem_fn(&wxStfGraph::yFormatD2), this, std::placeholders::_1);
          break;
      case background:
          Vector_double::const_iterator max_el = std::max_element(trace.begin(), trace.end());
@@ -712,7 +712,7 @@ void wxStfGraph::DoPlot( wxDC* pDC, const Vector_double& trace, int start, int e
          WindowRect.height /= Doc()->size();
          FittorectY(yzoombg, WindowRect, min, max, 1.0);
          yzoombg.startPosY += bgno*WindowRect.height;
-         yFormatFunc = std::bind1st( std::mem_fun(&wxStfGraph::yFormatDB), this);
+         yFormatFunc = std::bind( std::mem_fn(&wxStfGraph::yFormatDB), this, std::placeholders::_1);
          break;
     }
 
@@ -832,10 +832,10 @@ void wxStfGraph::DoPrint( wxDC* pDC, const Vector_double& trace, int start, int
     
     switch (ptype) {
      case active:
-         yFormatFunc = std::bind1st( std::mem_fun(&wxStfGraph::yFormatD), this);
+         yFormatFunc = std::bind( std::mem_fn(&wxStfGraph::yFormatD), this, std::placeholders::_1);
          break;
      default:
-         yFormatFunc = std::bind1st( std::mem_fun(&wxStfGraph::yFormatD2), this);
+         yFormatFunc = std::bind( std::mem_fn(&wxStfGraph::yFormatD2), this, std::placeholders::_1);
          break;
     }
 
@@ -2091,7 +2091,7 @@ void wxStfGraph::FitToWindowSecCh(bool refresh)
     }
 }	//End FitToWindowSecCh()
 
-void wxStfGraph::ChangeTrace(int trace) {
+void wxStfGraph::ChangeTrace(std::size_t trace) {
     stf::SectionAttributes sec_attr = Doc()->GetCurrentSectionAttributes();
     if (!sec_attr.eventList.empty() && trace != Doc()->GetCurSecIndex()) {
         for (event_it it2 = sec_attr.eventList.begin(); it2 != sec_attr.eventList.end(); ++it2) {
